==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_cs.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Mám takové tušení, že jsme na stopě něčeho strašného.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Vědel jsem to už dávno: bohové musí být šílení.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Bůh je šílený a celý svět je jeho hračka.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Myslím, že máš výjímečně pravdu.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Dnes ti bohužel musím dát za pravdu.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ano, je to otřesné.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Co s tím uděláme?")


dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Takhle to nemůže zůstat. Musíme je internovat.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Cože je musíme?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Zavřít do cvok... chci říct do nápravně-výchovného zařízení FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Máš pravdu. Vezmem je oba?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Samozřejmě. Kdyby tu jeden zůstal, kdo ví, co by ho napadlo. Třeba by chtěl začít hrát golf.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("S touhle holí těžko. Myslím, že budeme rádi, když dostaneme jednoho. Ten druhý už nebude nebezpečný.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Tak dobře. A koho?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Toho žlutého.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Toho modrého.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Toho žlutého.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Toho modrého.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Necháme to na hráči.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Necháme to na hráči.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Podívej se na tu hůl: té se stalo něco strašného.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Asi ji ožižlával pld.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Maminka měla pravdu: Příčinou všeho zla je chorobná hravost.")


dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("To je pravda. Oč by to bylo snadnější, kdyby támhle nebyla ta ping-pongová pálka.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Všimla sis mimochodem, že skutečný golfový míček je vlevo nahoře, zatímco vpravo dole je míček na kriket?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Myslíš, že to má nějaký skrytý význam?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Kdo ví?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Měla jsem pocit, že to nahoře je ping-pongový míček.")


dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Těžko říci, při tomhle rozlišení.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Naším úkolem je tentokrát dostat ven z místnosti kteréhokoliv z těch bohů.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Vyhrál jsem, saláte!!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Začínám já!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Dobře!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Dáme si ještě jednou?")


dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Nepodvádím!!!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Asi jsem se spletl...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Cha cha cha cha chá... vyhrál jsem!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Dobře!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zkusíme to ještě jednou?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("To jsi už zkoušel!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Tohle jsi už říkal!")


dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Na tomhle poli nemůže být voda!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Ty podvádíš!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("Tohle jsem už zkoušel - a ty jsi řekl 'voda'!")


dialogId("b1-1", "", "")
dialogStr("")


dialogId("b1-2", "", "")
dialogStr("")


dialogId("b1-3", "", "")
dialogStr("")


dialogId("b1-4", "", "")
dialogStr("")


dialogId("b1-5", "", "")
dialogStr("")


dialogId("b1-6", "", "")
dialogStr("")


dialogId("b1-7", "", "")
dialogStr("")


dialogId("b1-8", "", "")
dialogStr("")


dialogId("b1-9", "", "")
dialogStr("")


dialogId("b1-10", "", "")
dialogStr("")


dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b2-1", "", "")
dialogStr("")


dialogId("b2-2", "", "")
dialogStr("")


dialogId("b2-3", "", "")
dialogStr("")


dialogId("b2-4", "", "")
dialogStr("")


dialogId("b2-5", "", "")
dialogStr("")


dialogId("b2-6", "", "")
dialogStr("")


dialogId("b2-7", "", "")
dialogStr("")


dialogId("b2-8", "", "")
dialogStr("")


dialogId("b2-9", "", "")
dialogStr("")


dialogId("b2-10", "", "")
dialogStr("")


dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_cs.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Mám takové tušení, že jsme na stopě něčeho strašného.")


dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("Vědel jsem to už dávno: bohové musí být šílení.")


dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Bůh je šílený a celý svět je jeho hračka.")


dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Myslím, že máš výjímečně pravdu.")


dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Dnes ti bohužel musím dát za pravdu.")


dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Ano, je to otřesné.")


dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Co s tím uděláme?")


dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Takhle to nemůže zůstat. Musíme je internovat.")


dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Cože je musíme?")


dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Zavřít do cvok... chci říct do nápravně-výchovného zařízení FDTO.")


dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Máš pravdu. Vezmem je oba?")


dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Samozřejmě. Kdyby tu jeden zůstal, kdo ví, co by ho napadlo. Třeba by chtěl začít hrát golf.")


dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("S touhle holí těžko. Myslím, že budeme rádi, když dostaneme jednoho. Ten druhý už nebude nebezpečný.")


dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Tak dobře. A koho?")


dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Toho žlutého.")


dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Toho modrého.")


dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Toho žlutého.")


dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Toho modrého.")


dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Necháme to na hráči.")


dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Necháme to na hráči.")


dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Podívej se na tu hůl: té se stalo něco strašného.")


dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Asi ji ožižlával pld.")


dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Maminka měla pravdu: Příčinou všeho zla je chorobná hravost.")


dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("To je pravda. Oč by to bylo snadnější, kdyby támhle nebyla ta ping-pongová pálka.")


dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Všimla sis mimochodem, že skutečný golfový míček je vlevo nahoře, zatímco vpravo dole je míček na kriket?")


dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Myslíš, že to má nějaký skrytý význam?")


dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Kdo ví?")


dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Měla jsem pocit, že to nahoře je ping-pongový míček.")


dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Těžko říci, při tomhle rozlišení.")


dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Naším úkolem je tentokrát dostat ven z místnosti kteréhokoliv z těch bohů.")


dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Voda!")


dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Zásah!")


dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Potopená!")


dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Vyhrál jsem, saláte!!!")


dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Začínám já!")


dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Dobře!")


dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Dáme si ještě jednou?")


dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Nepodvádím!!!")


dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("Asi jsem se spletl...")


dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Voda!")


dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Zásah!")


dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Potopená!")


dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Cha cha cha cha chá... vyhrál jsem!")


dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Dobře!")


dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Zkusíme to ještě jednou?")


dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("To jsi už zkoušel!")


dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("Tohle jsi už říkal!")


dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Na tomhle poli nemůže být voda!")


dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Ty podvádíš!!!")


dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("Tohle jsem už zkoušel - a ty jsi řekl 'voda'!")


dialogId("b1-1", "", "")
dialogStr("")


dialogId("b1-2", "", "")
dialogStr("")


dialogId("b1-3", "", "")
dialogStr("")


dialogId("b1-4", "", "")
dialogStr("")


dialogId("b1-5", "", "")
dialogStr("")


dialogId("b1-6", "", "")
dialogStr("")


dialogId("b1-7", "", "")
dialogStr("")


dialogId("b1-8", "", "")
dialogStr("")


dialogId("b1-9", "", "")
dialogStr("")


dialogId("b1-10", "", "")
dialogStr("")


dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")


dialogId("b2-1", "", "")
dialogStr("")


dialogId("b2-2", "", "")
dialogStr("")


dialogId("b2-3", "", "")
dialogStr("")


dialogId("b2-4", "", "")
dialogStr("")


dialogId("b2-5", "", "")
dialogStr("")


dialogId("b2-6", "", "")
dialogStr("")


dialogId("b2-7", "", "")
dialogStr("")


dialogId("b2-8", "", "")
dialogStr("")


dialogId("b2-9", "", "")
dialogStr("")


dialogId("b2-10", "", "")
dialogStr("")


dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")


dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")
